@@ -6,14 +6,8 @@ import os
 import sys
 import tempfile
 import urllib
-
 from PIL import Image
-
 import numpy as np
-from aetros.Trainer import Trainer
-from aetros.keras_model_utils import ensure_dir
-from aetros.backend import JobBackend
-
 
 class JobModel:
     """
@@ -36,7 +30,7 @@ class JobModel:
 
     @property
     def insights_enabled(self):
-        return self.config['insights']
+        return 'insights' in self.config and self.config['insights']
 
     def get_model_node(self, name):
         if not isinstance(self.layers, list):
@@ -56,22 +50,22 @@ class JobModel:
         return self.job['config']['batchSize']
 
     def get_model_h5_path(self):
-        return os.getcwd() + '/aetros/model.h5'
+        return os.path.normpath(os.getcwd() + '/aetros/model.h5')
 
     def get_layers_path(self):
-        return os.getcwd() + '/aetros/layer.json'
+        return os.path.normpath(os.getcwd() + '/aetros/layer.json')
 
     def get_dataset_dir(self):
-        return os.getcwd() + '/aetros/dataset/'
+        return os.path.normpath(os.getcwd() + '/aetros/dataset')
 
     def get_dataset_downloads_dir(self, dataset):
-        return self.storage_dir + '/aetros/dataset/%s/datasets_downloads' % (dataset['id'],)
+        return os.path.normpath(self.storage_dir + '/aetros/dataset/%s/datasets_downloads' % (dataset['id'],))
 
     def get_weights_filepath_latest(self):
-        return os.getcwd() + '/aetros/weights_latest.hdf5'
+        return os.path.normpath(os.getcwd() + '/aetros/weights/latest.hdf5')
 
     def get_weights_filepath_best(self):
-        return os.getcwd() + '/aetros/weights_best.hdf5'
+        return os.path.normpath(os.getcwd() + '/aetros/weights/best.hdf5')
 
     def get_input_names(self):
         names = []
@@ -107,43 +101,32 @@ class JobModel:
                 trainer.input_shape = shape
 
     def is_python_model(self):
-        return 'fromCode' in self.job['config'] and self.job['config']['fromCode']
+        return 'type' in self.job['config'] and self.job['config']['type'] != 'simple'
 
     def is_keras_model(self):
-        return 'fromCode' not in self.job['config'] or not self.job['config']['fromCode']
+        return 'type' in self.job['config'] and self.job['config']['type'] == 'simple'
 
     def get_built_model(self, trainer):
+        # its built with model designer
+        model_provider = self.get_model_provider()
+        model = model_provider.get_model(trainer)
 
-        if 'fromCode' in self.job['config'] and self.job['config']['fromCode']:
-            # its built with custom code using KerasIntegration class
-            from keras.models import model_from_json
-            model = model_from_json(self.job['config']['model'])
-            return model
-        else:
+        loss = model_provider.get_loss(trainer)
+        optimizer = model_provider.get_optimizer(trainer)
 
-            if 'classes' in self.job['info']:
-                trainer.output_size = len(self.job['info']['classes'])
-
-            # its built with model designer
-            model_provider = self.get_model_provider()
-            model = model_provider.get_model(trainer)
-
-            loss = model_provider.get_loss(trainer)
-            optimizer = model_provider.get_optimizer(trainer)
-
-            model_provider.compile(trainer, model, loss, optimizer)
+        model_provider.compile(trainer, model, loss, optimizer)
 
         return model
 
-    def predict(self, model, input):
-        prediction = model.predict(input)
+    def predict(self, trainer, input):
+        prediction = trainer.model.predict(input)
 
         top5 = np.argsort(-prediction[0])[:5]
 
         result = []
         for i in top5:
             result.append({
-                'class': self.get_dataset_class_label(self.get_first_output_layer(), i),
+                'class': self.get_dataset_class_label(trainer, self.get_first_output_layer(), i),
                 'prediction': float(prediction[0][i])
             })
 
@@ -173,7 +156,7 @@ class JobModel:
         else:
             try:
                 image = Image.open(local_path)
-            except:
+            except Exception:
                 print(("Could not open %s" % (local_path,)))
                 return []
 
@@ -236,11 +219,12 @@ class JobModel:
             self._datasets = {}
 
             def read_dataset(id):
-                with open(self.get_dataset_dir() + id + '.json', 'r') as f:
+                dataset_json_path = os.path.normpath(self.get_dataset_dir() + '/' + id + '.json')
+                with open(dataset_json_path, 'r') as f:
                     self._datasets[id] = json.loads(f.read())
 
             for owner in os.listdir(self.get_dataset_dir()):
-                path = self.get_dataset_dir() + owner + '/dataset/'
+                path = os.path.normpath(self.get_dataset_dir() + '/' + owner + '/dataset/')
                 for name in os.listdir(path):
                     if name.endswith('.json'):
                         read_dataset(owner + '/dataset/' + name[:-len('.json')])
@@ -292,45 +276,55 @@ class JobModel:
                 elif dataset['type'] == 'python':
                     name = dataset['id']
 
-                    sys.path.append(sys.path.abspath('./aetros/'))
-                    data_provider = __import__(name, '')
-                    print("Imported dataset provider from %s " % (os.path.abspath('./aetros/' + name + '.py'),))
-                    sys.path.pop()
-                    import inspect
-                    argSpec = inspect.getargspec(data_provider.get_data)
+                    try:
+                        sys.path.append(os.path.abspath('./aetros/dataset/' + os.path.dirname(name)))
+                        data_provider = __import__(os.path.basename(name))
+                        print("Imported dataset provider from %s " % (os.path.abspath('./aetros/dataset/' + name + '.py'),))
 
-                    if len(argSpec.args) > 0:
-                        datasets[dataset['id']] = data_provider.get_data(trainer)
-                    else:
-                        datasets[dataset['id']] = data_provider.get_data()
+                        import inspect
+                        argSpec = inspect.getargspec(data_provider.get_data)
+
+                        if len(argSpec.args) > 0:
+                            datasets[dataset['id']] = data_provider.get_data(trainer)
+                        else:
+                            datasets[dataset['id']] = data_provider.get_data()
+
+                    except Exception:
+                        trainer.logger.error('Could not import dataset code: ' + name + ' in ' + os.path.abspath('./aetros/dataset/'))
+                        raise
+                    finally:
+                        sys.path.pop()
 
         return datasets
 
-    def get_dataset_class_label(self, output_layer, prediction):
+    def get_dataset_class_label(self, trainer, output_layer, prediction):
         dataset_id = output_layer['datasetId']
         dataset = self.datasets[dataset_id]
+
         if not dataset:
             raise Exception('Dataset of id %s does not exists. Available %s' % (
             dataset_id, ','.join(list(self.datasets.keys()))))
 
-        if 'classes' in self.job['info']:
-            return self.job['info']['classes'][prediction]
+        if trainer.classes:
+            return trainer.classes[prediction]
 
         elif dataset['type'] == 'python':
-            name = dataset['id'].replace('/', '__')
-
+            name = dataset['id']
             datasets_dir = self.get_dataset_dir()
             try:
-                sys.path.append(datasets_dir)
-                data_provider = __import__(name, '')
-                sys.path.pop()
+                sys.path.append(os.path.abspath('./aetros/dataset/' + os.path.dirname(name)))
+                data_provider = __import__(os.path.basename(name))
+
                 if hasattr(data_provider, 'get_class_label'):
                     return data_provider.get_class_label(prediction)
                 else:
                     return prediction
-            except Exception as e:
+            except Exception:
                 print(("Method get_class_label failed in %s " % (datasets_dir + '/' + name + '.py',)))
-                raise e
+                raise
+            finally:
+                sys.path.pop()
+
 
     def get_first_input_layer(self):
         config = self.job['config']
