@@ -1,4 +1,4 @@
-__version__ = '0.10.3'
+__version__ = '0.11.1'
 __prog__ = "aetros"
 
 class bcolors:
@@ -17,4 +17,4 @@ class JOB_STATUS:
     PROGRESS_STATUS_STARTED = 2
     PROGRESS_STATUS_DONE = 3
     PROGRESS_STATUS_ABORTED = 4
-    PROGRESS_STATUS_CRASHED = 5
\ No newline at end of file
+    PROGRESS_STATUS_FAILED = 5
\ No newline at end of file
