@@ -31,7 +31,7 @@ def get_total_params(model):
     return total_params
 
 
-def job_start(job_backend, trainer, keras_logger):
+def job_start(job_backend, trainer, keras_callback):
     """
     Starts the training of a job. Needs job_prepare() first.
 
@@ -70,14 +70,14 @@ def job_start(job_backend, trainer, keras_logger):
             else:
                 insights_x = dataset['X_train'][0]
 
-    keras_logger.insights_x = insights_x
-    print('Insights sample shape', keras_logger.insights_x.shape)
-    keras_logger.write("Possible data keys '%s'\n" % "','".join(list(datasets.keys())))
+    keras_callback.insights_x = insights_x
+    print('Insights sample shape', keras_callback.insights_x.shape)
+    keras_callback.write("Possible data keys '%s'\n" % "','".join(list(datasets.keys())))
 
     data_train = model_provider.get_training_data(trainer, datasets)
     data_validation = model_provider.get_validation_data(trainer, datasets)
 
-    keras_logger.set_validation_data(data_validation, trainer.nb_val_samples)
+    keras_callback.set_validation_data(data_validation, trainer.nb_val_samples)
 
     trainer.set_status('CONSTRUCT')
     model = model_provider.get_model(trainer)
@@ -89,7 +89,7 @@ def job_start(job_backend, trainer, keras_logger):
     model_provider.compile(trainer, model, loss, optimizer)
     model.summary()
 
-    trainer.callbacks.append(keras_logger)
+    trainer.callbacks.append(keras_callback)
     model_provider.train(trainer, model, data_train, data_validation)
 
 
